Boost Graph Library: Property Map Traits

#

    property_map<PropertyGraph, PropertyTag>

This is the traits class that produces the type for a property map object for a particular graph type. The property is specified by the PropertyTag template parameter. Graph classes must specialize this traits class to provide their own implementation for property maps.

      template <class Graph, class PropertyTag>
      struct property_map {
        typedef ... type;
        typedef ... const_type;
      };

### Where Defined

`boost/graph/properties.hpp`

### Associated Types

Map Type | `type` | The (mutable) property map type for mapping vertex or edge desriptors of the graph to their associated property values, where the property is specified by `PropertyTag`. This type is a property map.
Const Map Type | `const_type` | The (non-mutable) property map type for mapping vertex or edge desriptors of the graph to their associated property values, where the property is specified by `PropertyTag`. This type is a property map.

Copyright © 2000-2001 | Jeremy Siek, Indiana University (jsiek@osl.iu.edu) Lie-Quan Lee, Indiana University (llee@cs.indiana.edu) Andrew Lumsdaine, Indiana University (lums@osl.iu.edu)